@@ -2,8 +2,10 @@ package inspect
 
 import (
 	"bytes"
+	"context"
 	"encoding/json"
 	"fmt"
+	"io"
 	"os"
 	"path"
 	"strings"
@@ -13,15 +15,10 @@ import (
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	utilerrors "k8s.io/apimachinery/pkg/util/errors"
 	"k8s.io/client-go/rest"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 )
 
 func (o *InspectOptions) gatherPodData(destDir, namespace string, pod *corev1.Pod) error {
-	if pod.Status.Phase != corev1.PodRunning {
-		klog.V(1).Infof("        Skipping container data collection for pod %q: Pod not running\n", pod.Name)
-		return nil
-	}
-
 	// ensure destination path exists
 	if err := os.MkdirAll(destDir, os.ModePerm); err != nil {
 		return err
@@ -34,14 +31,6 @@ func (o *InspectOptions) gatherPodData(destDir, namespace string, pod *corev1.Po
 
 	errs := []error{}
 
-	// skip gathering container data if containers are no longer running
-	if running, err := PodRunningReady(pod); err != nil {
-		return err
-	} else if !running {
-		klog.V(1).Infof("        Skipping container data collection for pod %q: Pod not running\n", pod.Name)
-		return nil
-	}
-
 	// gather data for each container in the given pod
 	for _, container := range pod.Spec.Containers {
 		if err := o.gatherContainerInfo(path.Join(destDir, "/"+container.Name), pod, container); err != nil {
@@ -229,36 +218,48 @@ func (o *InspectOptions) gatherContainerHealthz(destDir string, pod *corev1.Pod,
 		return fmt.Errorf("unable to find any available /healthz paths hosted in pod %q", pod.Name)
 	}
 
-	for _, healthzPath := range healthzPaths {
-		result, err := o.podUrlGetter.Get(path.Join("/", healthzPath), pod, o.restConfig, metricsPort)
-		if err != nil {
-			// TODO: aggregate errors
-			return err
-		}
+	err = o.podUrlGetter.ForwardRequests(pod, o.restConfig, metricsPort, func(restClient rest.Interface) error {
+		for _, healthzPath := range healthzPaths {
+			ioCloser, err := restClient.Get().RequestURI(path.Join("/", healthzPath)).Stream(context.TODO())
+			if err != nil {
+				return err
+			}
+			defer ioCloser.Close()
 
-		if len(healthzSeparator) > len(healthzPath) {
-			continue
-		}
-		filename := healthzPath[len(healthzSeparator):]
-		if len(filename) == 0 {
-			filename = "index"
-		} else {
-			filename = strings.TrimPrefix(filename, "/")
-		}
+			data := bytes.NewBuffer(nil)
+			if _, err := io.Copy(data, ioCloser); err != nil {
+				return err
+			}
 
-		filenameSegs := strings.Split(filename, "/")
-		if len(filenameSegs) > 1 {
-			// ensure directory structure for nested paths exists
-			filenameSegs = filenameSegs[:len(filenameSegs)-1]
-			if err := os.MkdirAll(path.Join(destDir, "/"+strings.Join(filenameSegs, "/")), os.ModePerm); err != nil {
+			if len(healthzSeparator) > len(healthzPath) {
+				continue
+			}
+			filename := healthzPath[len(healthzSeparator):]
+			if len(filename) == 0 {
+				filename = "index"
+			} else {
+				filename = strings.TrimPrefix(filename, "/")
+			}
+
+			filenameSegs := strings.Split(filename, "/")
+			if len(filenameSegs) > 1 {
+				// ensure directory structure for nested paths exists
+				filenameSegs = filenameSegs[:len(filenameSegs)-1]
+				if err := os.MkdirAll(path.Join(destDir, "/"+strings.Join(filenameSegs, "/")), os.ModePerm); err != nil {
+					return err
+				}
+			}
+
+			if err := o.fileWriter.WriteFromSource(path.Join(destDir, filename), &TextWriterSource{Text: data.String()}); err != nil {
 				return err
 			}
 		}
-
-		if err := o.fileWriter.WriteFromSource(path.Join(destDir, filename), &TextWriterSource{Text: result}); err != nil {
-			return err
-		}
+		return nil
+	})
+	if err != nil {
+		return err
 	}
+
 	return nil
 }
 
@@ -292,8 +293,8 @@ func (o *InspectOptions) gatherContainerLogs(destDir string, pod *corev1.Pod, co
 	wg := sync.WaitGroup{}
 	errLock := sync.Mutex{}
 
+	wg.Add(1)
 	go func() {
-		wg.Add(1)
 		defer wg.Done()
 
 		innerErrs := []error{}
@@ -303,6 +304,12 @@ func (o *InspectOptions) gatherContainerLogs(destDir string, pod *corev1.Pod, co
 			Previous:   false,
 			Timestamps: true,
 		}
+		if len(o.sinceTime) > 0 {
+			logOptions.SinceTime = &o.sinceTimestamp
+		}
+		if o.since != 0 {
+			logOptions.SinceSeconds = &o.sinceInt
+		}
 		filename := "current.log"
 		logsReq := o.kubeClient.CoreV1().Pods(pod.Namespace).GetLogs(pod.Name, logOptions)
 		if err := o.fileWriter.WriteFromSource(path.Join(destDir, "/"+filename), logsReq); err != nil {
@@ -321,9 +328,8 @@ func (o *InspectOptions) gatherContainerLogs(destDir string, pod *corev1.Pod, co
 		defer errLock.Unlock()
 		errs = append(errs, innerErrs...)
 	}()
-
+	wg.Add(1)
 	go func() {
-		wg.Add(1)
 		defer wg.Done()
 
 		innerErrs := []error{}
@@ -351,6 +357,6 @@ func (o *InspectOptions) gatherContainerLogs(destDir string, pod *corev1.Pod, co
 		defer errLock.Unlock()
 		errs = append(errs, innerErrs...)
 	}()
-
+	wg.Wait()
 	return utilerrors.NewAggregate(errs)
 }
